from django.db import models
from django.contrib.auth.models import User
from PIL import Image
import environ
# Initialise environment variables
env = environ.Env()
environ.Env.read_env()
CREDITS_ON_PROFILE_CREATE = int(env('CREDITS_ON_PROFILE_CREATE'))

class Profile(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, null=True, related_name='profile')
    ACCOUNT_TYPE = (('0', 'Free Account'), ('1', 'Premium Account'))
    type = models.CharField(max_length=1, choices=ACCOUNT_TYPE, blank=True, default='0',
                            help_text="Account type 0: Free Account, 1: Premium Account")
    credits = models.PositiveIntegerField("Credits", default=0)
    spend = models.FloatField("Spend", default=0.00)
    created_at = models.DateTimeField("Created at", auto_now_add=True)
    updated_at = models.DateTimeField("Updated at", auto_now=True)

    def save(self, *args, **kwargs):
        if not self.pk:
            self.credits = CREDITS_ON_PROFILE_CREATE
        super().save(*args, **kwargs)
    def __str__(self):
        return f"{self.user}"

class GeneratedImageFromTxt(models.Model):
    txt = models.CharField("Text", max_length=1500)
    generated_img = models.ImageField(upload_to="Generated_img_from_txt",)
    selected_for_index = models.BooleanField("Selected for index", default=False)
    profile = models.ForeignKey("Profile",on_delete=models.CASCADE, related_name='generated_img_from_txt')
    created_at = models.DateTimeField("Created at", auto_now_add=True)
    updated_at = models.DateTimeField("Updated at", auto_now=True)

    class Meta:
        ordering = ['-created_at']
    def __str__(self):
        return f"{self.generated_img}, {self.profile}"

class Product(models.Model):
    name = models.CharField(max_length=100)
    price = models.IntegerField(default=0)  # cents
    coins = models.IntegerField(default=0)
    custom_id = models.IntegerField("Custom ID", default=0)

    # url = models.URLField()

    def __str__(self):
        return f"{self.name}, {self.custom_id}"

    def get_display_price(self):
        return "{0:.2f}".format(self.price / 100)



